import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * Manage a Fastly service version.
 *
 * @schema CfnVersionProps
 */
export interface CfnVersionProps {
    /**
     * Alphanumeric string identifying the service. Read-only.
     *
     * @schema CfnVersionProps#ServiceId
     */
    readonly serviceId: string;
    /**
     * @schema CfnVersionProps#CreatedAt
     */
    readonly createdAt?: Date;
    /**
     * @schema CfnVersionProps#UpdatedAt
     */
    readonly updatedAt?: Date;
    /**
     * @schema CfnVersionProps#DeletedAt
     */
    readonly deletedAt?: Date;
}
/**
 * Converts an object of type 'CfnVersionProps' to JSON representation.
 */
export declare function toJson_CfnVersionProps(obj: CfnVersionProps | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Fastly::Services::Version`
 *
 * @cloudformationResource Fastly::Services::Version
 * @stability external
 * @link https://github.com/aws-ia/cloudformation-fastly-resource-providers.git
 */
export declare class CfnVersion extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Fastly::Services::Version";
    /**
     * Resource props.
     */
    readonly props: CfnVersionProps;
    /**
     * Attribute `Fastly::Services::Version.VersionNumber`
     * @link https://github.com/aws-ia/cloudformation-fastly-resource-providers.git
     */
    readonly attrVersionNumber: number;
    /**
     * Create a new `Fastly::Services::Version`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnVersionProps);
}
